%  PredPreyScript.m:  The script file to run the predator-prey example:
%     dA/dt = 2 A - 1.2 A*B   
%     dB/dt = - B + 0.9 A*B
%  The system of differential equations is specified in the file
%  pred_prey_odes.m

%  Define initial and final times
t0 = 0;
tf = 20;

%  Define initial values vector with A(0) = 1, and B(0) = 0.5
init_vals = [0; 0.5]

%  Use ode45 to generate approximations to the solution.  Keep in mind that
%  t is a vector of one dimension, just time, but x will be a matrix.  It's
%  first row will contain the A(t) values and it's second row will contain
%  the B(t) values.
options=odeset('AbsTol',1.e-12,'RelTol',1.e-9,'InitialStep',2,'MaxStep',2); 
[t,x] = ode45(@pred_prey_odes,[t0,tf],init_vals,options);

%  Peel off our A(t) and B(t) values for easier reading and plotting:
A = x(1,:);  %  A is the first row of the x matrix, collecing all columns.
B = x(2,:);  %  B is the second row of the x matrix, collecting all columns

%  Plot A(t) values in red with *'s, B(t) values in blue with circles.
plot(t,A,'r*-',t,B,'bo:')
title('Our Predator Prey Example, Solutions Over Time')
legend('Prey','Predator')

%  Plot the phase plane, A-values versus B-values
figure %  This opens a new window for an additional plot
plot(A,B) 
title('Phase Plane for Predator Prey Example')

