%  Simple Example
%  Initial Value Problem:
%    dx/dt = 2*x*t,  x(0) = 1  (Differential equation stored in file:
%    dfdt.m)
%  True solution is x(t) = exp(t^2).

%  Use ode45 to generate the vector of t and x-values in the solution:
%  [t,x]=ode45(@function_file_name, [start_time, end_time], initial_value)
%  Note the "@" needed in front of the function file name (and lack of ".m")
options=odeset('AbsTol',1.e-12,'RelTol',1.e-9,'InitialStep',2,'MaxStep',2); 
[t,x] = ode45(@dfdt,[0,0.5],1,options);

%  Plot our numerical approximation in red using *'s to mark the points:
plot(t,x,'r*')

hold on %  Hold that plot

%  Create a vector of independent variable (t) values from 0 to 0.5, spaced
%  0.01 apart.  Then calculate their associated x(t) values, exp(t^2).
tvals = [0:0.01:0.5];  
true_solution = exp(tvals.^2);

%  Plot the true solution in blue
plot(tvals,true_solution,'b');

%  Add a legend to the plot
legend('Approximation','True Solution')

fprintf('t \t x(t) \t true \t err \n');
for i=1:length(x)
    xval = x(i);
    true_val = exp(t(i)^2);
    err = abs(x(i) - true_val);
    fprintf('%f \t &  %12.10f \t & %12.10f \t & %12.10f \n',t(i), xval, true_val, err);
end;
