function deriv_vals = pred_prey_odes(t,x)
%  We're calculating the values of the differential equations:
%     dA/dt = 2 A - 1.2 A*B   or deriv_vals = [ 2*x(1) - 1.2*x(1)*x(2) ]
%     dB/dt = - B + 0.9 A*B                   [ -x(2) + 0.9*x(1)*x(2)  ]
%  But we assume our input vector, x, is really:
%              [ A ]
%           x =[   ]
%              [ B ]
%  so x(1) = A and x(2) = B.

%  Generate a vector of zeros the same size as the vector x.  The 0's are
%  just placeholders for our dA/dt and dB/dt values (or dx(1)/dt and
%  dx(2)/dt values)
deriv_vals = zeros(size(x));

%  Calculate dA/dt, the first value in the deriv_vals vector.  Remember A =
%  x(1) and B = x(2).
deriv_vals(1) = 2*x(1) - 1.2*x(1).*x(2);

%  Calculate dB/dt, the second value in the deriv_vals vector.  Remember A =
%  x(1) and B = x(2).
deriv_vals(2) = -1*x(2) + 0.9*x(1).*x(2);